.. -*- coding: utf-8 -*-


===================
 Vesicles datasets
===================

.. module:: MDAnalysisData.vesicles

The :mod:`MDAnalysisData.vesicles` module gives access to structures
of vesicle models. These models were constructed with the coarse
grained Martini force field. The data can be used to analyze lipid
membranes and to test working with large coarse grained systems.


.. currentmodule:: MDAnalysisData.vesicles

.. autosummary::

   fetch_vesicle_lib




.. include:: ../MDAnalysisData/descr/vesicle_lib.rst

.. autofunction:: fetch_vesicle_lib

		  
